# Granola changelog

## [0.1.9] - 2026-02-27
- Updated connector definition (YAML version 1.0.2)
- Source commit: a735c402
- SDK version: 0.1.0

## [0.1.8] - 2026-02-27
- Updated connector definition (YAML version 1.0.2)
- Source commit: 7bd29cad
- SDK version: 0.1.0

## [0.1.7] - 2026-02-27
- Updated connector definition (YAML version 1.0.2)
- Source commit: 39690c8e
- SDK version: 0.1.0

## [0.1.6] - 2026-02-26
- Updated connector definition (YAML version 1.0.2)
- Source commit: 9072a725
- SDK version: 0.1.0

## [0.1.5] - 2026-02-23
- Updated connector definition (YAML version 1.0.2)
- Source commit: 62fbfc1f
- SDK version: 0.1.0

## [0.1.4] - 2026-02-20
- Updated connector definition (YAML version 1.0.2)
- Source commit: fc238ee4
- SDK version: 0.1.0

## [0.1.3] - 2026-02-20
- Updated connector definition (YAML version 1.0.1)
- Source commit: cb4380e7
- SDK version: 0.1.0

## [0.1.2] - 2026-02-19
- Updated connector definition (YAML version 1.0.1)
- Source commit: 7cda3ed1
- SDK version: 0.1.0

## [0.1.1] - 2026-02-19
- Updated connector definition (YAML version 1.0.1)
- Source commit: 3f4da97b
- SDK version: 0.1.0

## [0.1.0] - 2026-02-12
- Updated connector definition (YAML version 1.0.1)
- Source commit: 7afbc8f0
- SDK version: 0.1.0
